﻿using Microsoft.EntityFrameworkCore;
using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.ComponentModel.DataAnnotations.Schema;

namespace IRaCIS.Core.Domain.Models;

[Comment("项目中心 - 推送检查")]
[Table("SCPStudy")]
public class SCPStudy : BaseFullDeleteAuditEntity, IEntitySeqId
{

    #region 导航属性
    [JsonIgnore]
    public List<SCPInstance> InstanceList { get; set; }

    [JsonIgnore]
    public List<SCPSeries> SeriesList { get; set; }
    [JsonIgnore]
    public SubjectVisit SubjectVisit { get; set; }

    [JsonIgnore]
    public Trial Trial { get; set; }

    [JsonIgnore]
    public TrialSite TrialSite { get; set; }

    [ForeignKey("PatientId")]
    [JsonIgnore]
    public SCPPatient Patient { get; set; }

    #endregion

    public string AccessionNumber { get; set; } = null!;

    public string AcquisitionNumber { get; set; } = null!;

    public string AcquisitionTime { get; set; } = null!;

    [StringLength(512)]
    public string BodyPartExamined { get; set; } = null!;

    public string BodyPartForEdit { get; set; } = null!;

    public string CalledAE { get; set; } = null!;

    public string CallingAE { get; set; } = null!;

    [StringLength(1000)]
    public string Description { get; set; } = null!;

    public int InstanceCount { get; set; }

    public string InstitutionName { get; set; } = null!;

    public bool IsDoubleReview { get; set; }

    public bool IsUploadFinished { get; set; }

    public string Modalities { get; set; } = null!;

    public string ModalityForEdit { get; set; } = null!;

    public string PatientAge { get; set; } = null!;

    public string PatientBirthDate { get; set; } = null!;

    public Guid PatientId { get; set; }

    public string PatientIdStr { get; set; } = null!;

    public string PatientName { get; set; } = null!;

    public string PatientSex { get; set; } = null!;

    [Comment(" 序列Id 避免内存移动")]
    public Guid SeqId { get; set; }

    public int SeriesCount { get; set; }

    [Comment(" DicomTag.StudyID")]
    public string StudyId { get; set; } = null!;

    [StringLength(500)]
    public string StudyInstanceUid { get; set; } = null!;

    public DateTime? StudyTime { get; set; }

    public Guid? SubjectVisitId { get; set; }

    public Guid TrialId { get; set; }

    public Guid TrialSiteId { get; set; }

    public string TriggerTime { get; set; } = null!;

    [Comment(" 上传时间")]
    public DateTime? UploadedTime { get; set; }

    public string Uploader { get; set; } = null!;

}
