

using System;
using IRaCIS.Core.Domain.Share;
using System.ComponentModel.DataAnnotations;
using System.ComponentModel.DataAnnotations.Schema;
using System.Collections.Generic;
using Microsoft.EntityFrameworkCore;

namespace IRaCIS.Core.Domain.Models;

[Comment("项目阅片 - 一致性分析临床数据")]
[Table("ReadingConsistentClinicalData")]
public class ReadingConsistentClinicalData : BaseAddAuditEntity
{
    #region 导航属性
    [JsonIgnore]
    [ForeignKey("ClinicalDataTrialSetId")]

    public ClinicalDataTrialSet ClinicalDataTrialSet { get; set; }

    [JsonIgnore]
    [ForeignKey("StudyId")]
    public DicomStudy DicomStudy { get; set; }

    [JsonIgnore]
    [ForeignKey("TrialId")]

    public Trial Trial { get; set; }

    [JsonIgnore]
    [ForeignKey("ReadingId")]

    public SubjectVisit SubjectVisit { get; set; }

    [JsonIgnore]
    [ForeignKey("SubjectId")]

    public Subject Subject { get; set; }

    [JsonIgnore]
    [ForeignKey("ReadingId")]

    public ReadModule ReadModule { get; set; }

    /// <summary>
    /// PDF文件
    /// </summary>
    [JsonIgnore]
    public List<ReadingConsistentClinicalDataPDF> ReadingClinicalDataPDFList { get; set; }
    #endregion

    public Guid ClinicalDataTrialSetId { get; set; }

    public int FileCount { get; set; }
    [Comment("是否盲化")]
    public bool? IsBlind { get; set; }
    [Comment("是否完整")]
    public bool? IsComplete { get; set; }

    public bool IsSign { get; set; }

    public bool IsVisit { get; set; }

    public ReadingClinicalDataStatus ReadingClinicalDataState { get; set; }

    public Guid ReadingId { get; set; }

    public Guid? StudyId { get; set; }

    public Guid SubjectId { get; set; }

    public Guid TrialId { get; set; }

}



