﻿using IRaCIS.Core.Domain.Share;
using Microsoft.EntityFrameworkCore;
using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.ComponentModel.DataAnnotations.Schema;

namespace IRaCIS.Core.Domain.Models;

[Comment("医生 - 入组项目中间记录表")]
[Table("Enroll")]
public partial class Enroll : BaseFullAuditEntity
{
    #region 导航属性
    [JsonIgnore]
    [ForeignKey("TrialId")]
    public virtual Trial Trial { get; set; }
    [JsonIgnore]
    public virtual Doctor Doctor { get; set; }
    [JsonIgnore]
    public User DoctorUser { get; set; }


    [JsonIgnore]
    public List<EnrollReadingCategory> EnrollReadingCategoryList { get; set; }

    [JsonIgnore]
    public List<EnrollReadingCriterion> EnrollReadingCriteriaList { get; set; }
    #endregion


    [Comment(" 裁定")]
    public int? Adjudication { get; set; }

    [Comment(" 裁定24小时")]
    public int? Adjudication24H { get; set; }

    [Comment(" 裁定48小时")]
    public int? Adjudication48H { get; set; }

    [Comment(" 价格")]
    [DecimalPrecision(18, 2)] 
    public decimal? AdjustmentMultiple { get; set; }

    public Guid? AttachmentId { get; set; }

    public Guid DoctorId { get; set; }

    public int DoctorTrialState { get; set; }

    [Comment(" 生成账号 加入到项目中后 赋值")] 
    public Guid? DoctorUserId { get; set; }

    [Comment(" 空跑")]
    public int? Downtime { get; set; }

    [Comment(" 入组状态")]
    public EnrollStatus EnrollStatus { get; set; }

    [Comment(" 入组时间")]
    public DateTime? EnrollTime { get; set; }

    [Comment(" 总体")]
    public int? Global { get; set; }

    [StringLength(500)]
    public string Memo { get; set; } = null!;

    [Comment(" 出组时间")]
    public DateTime? OutEnrollTime { get; set; }

    [Comment(" 重新培训")]
    public int? RefresherTraining { get; set; }

    [Comment(" 0代表裁判和TP都可以  1代表Tp  2 代表裁判")]
    public int ReviewerReadingType { get; set; }

    [Comment(" 时间点")]
    public int? Timepoint { get; set; }

    [Comment(" 时间点24小时")]
    public int? Timepoint24H { get; set; }

    [Comment(" 时间点48小时")]
    public int? Timepoint48H { get; set; }

    [Comment(" 培训")]
    public int? Training { get; set; }

    public Guid TrialId { get; set; }


}
